@@ -1,42 +1,42 @@
 import pytest
 
 from yamlpath.exceptions import YAMLPathException
-from yamlpath.enums import PathSegmentTypes, PathSeperators
+from yamlpath.enums import PathSegmentTypes, PathSeparators
 from yamlpath import YAMLPath
 
 class Test_YAMLPath():
     """Tests for the Path class."""
 
     @pytest.mark.parametrize("yamlpath,pathsep,output", [
-        (YAMLPath(""), PathSeperators.AUTO, ""),
-        (YAMLPath("abc"), PathSeperators.AUTO, "abc"),
-        ("abc", PathSeperators.AUTO, "abc"),
-        ("/abc", PathSeperators.AUTO, "/abc"),
-        ("abc.bcd", PathSeperators.AUTO, "abc.bcd"),
-        ("/abc[1]", PathSeperators.AUTO, "/abc[1]"),
-        ("&abc", PathSeperators.AUTO, "&abc"),
-        ("/abc[&def]", PathSeperators.AUTO, "/abc[&def]"),
-        ("abc[!def^ghi]", PathSeperators.AUTO, "abc[def!^ghi]"),
-        ("/(abc)[0]", PathSeperators.AUTO, "/(abc)[0]"),
-        ("abc[def =~ /ghi/]", PathSeperators.AUTO, "abc[def=~/ghi/]"),
-        ("/(abc)+(def)-(ghi)", PathSeperators.AUTO, "/(abc)+(def)-(ghi)"),
-        (r"abc.'def.g\"h\"i'", PathSeperators.AUTO, r"abc.def\.g\"h\"i"),
-        ("/abc[def>=1]", PathSeperators.AUTO, "/abc[def>=1]"),
-        ("abc[def<=10]", PathSeperators.AUTO, "abc[def<=10]"),
-        ("/abc[def==1]", PathSeperators.AUTO, "/abc[def=1]"),
-        ("abc[def$ghi]", PathSeperators.AUTO, "abc[def$ghi]"),
-        ("/abc[def%1]", PathSeperators.AUTO, "/abc[def%1]"),
-        ("abc[def%'ghi']", PathSeperators.AUTO, "abc[def%ghi]"),
-        ("abc*", PathSeperators.AUTO, "[.^abc]"),
-        ("*def", PathSeperators.AUTO, "[.$def]"),
-        ("a*f", PathSeperators.AUTO, "[.=~/^a.*f$/]"),
-        ("a*f*z", PathSeperators.AUTO, "[.=~/^a.*f.*z$/]"),
-        ("a*f*z*", PathSeperators.AUTO, "[.=~/^a.*f.*z.*$/]"),
-        ("*", PathSeperators.AUTO, "*"),
-        ("*.*", PathSeperators.AUTO, "*.*"),
-        ("**", PathSeperators.AUTO, "**"),
-        ("/**/def", PathSeperators.AUTO, "/**/def"),
-        ("abc.**.def", PathSeperators.AUTO, "abc.**.def"),
+        (YAMLPath(""), PathSeparators.AUTO, ""),
+        (YAMLPath("abc"), PathSeparators.AUTO, "abc"),
+        ("abc", PathSeparators.AUTO, "abc"),
+        ("/abc", PathSeparators.AUTO, "/abc"),
+        ("abc.bcd", PathSeparators.AUTO, "abc.bcd"),
+        ("/abc[1]", PathSeparators.AUTO, "/abc[1]"),
+        ("&abc", PathSeparators.AUTO, "&abc"),
+        ("/abc[&def]", PathSeparators.AUTO, "/abc[&def]"),
+        ("abc[!def^ghi]", PathSeparators.AUTO, "abc[def!^ghi]"),
+        ("/(abc)[0]", PathSeparators.AUTO, "/(abc)[0]"),
+        ("abc[def =~ /ghi/]", PathSeparators.AUTO, "abc[def=~/ghi/]"),
+        ("/(abc)+(def)-(ghi)", PathSeparators.AUTO, "/(abc)+(def)-(ghi)"),
+        (r"abc.'def.g\"h\"i'", PathSeparators.AUTO, r"abc.def\.g\"h\"i"),
+        ("/abc[def>=1]", PathSeparators.AUTO, "/abc[def>=1]"),
+        ("abc[def<=10]", PathSeparators.AUTO, "abc[def<=10]"),
+        ("/abc[def==1]", PathSeparators.AUTO, "/abc[def=1]"),
+        ("abc[def$ghi]", PathSeparators.AUTO, "abc[def$ghi]"),
+        ("/abc[def%1]", PathSeparators.AUTO, "/abc[def%1]"),
+        ("abc[def%'ghi']", PathSeparators.AUTO, "abc[def%ghi]"),
+        ("abc*", PathSeparators.AUTO, "[.^abc]"),
+        ("*def", PathSeparators.AUTO, "[.$def]"),
+        ("a*f", PathSeparators.AUTO, "[.=~/^a.*f$/]"),
+        ("a*f*z", PathSeparators.AUTO, "[.=~/^a.*f.*z$/]"),
+        ("a*f*z*", PathSeparators.AUTO, "[.=~/^a.*f.*z.*$/]"),
+        ("*", PathSeparators.AUTO, "*"),
+        ("*.*", PathSeparators.AUTO, "*.*"),
+        ("**", PathSeparators.AUTO, "**"),
+        ("/**/def", PathSeparators.AUTO, "/**/def"),
+        ("abc.**.def", PathSeparators.AUTO, "abc.**.def"),
     ])
     def test_str(self, yamlpath, pathsep, output):
         # Test twice to include cache hits
@@ -97,13 +97,26 @@ class Test_YAMLPath():
         else:
             assert not lhs != rhs
 
-    def test_seperator_change(self):
+    @pytest.mark.parametrize("sep_property", ["separator", "seperator"])
+    def test_separator_change(self, sep_property):
+        """`sep_property` is parametrized to ensure backward compatibility."""
         dotted = "abc.def"
         slashed = "/abc/def"
         testpath = YAMLPath(dotted)
-        testpath.seperator = PathSeperators.FSLASH
+        setattr(testpath, sep_property, PathSeparators.FSLASH)
         assert slashed == str(testpath) != dotted
 
+    @pytest.mark.parametrize("yamlpath, pathsep", [
+        ("abc.def", PathSeparators.DOT),
+        ("/abc/def", PathSeparators.FSLASH),
+    ])
+    def test_legacy_separator_access(self, yamlpath, pathsep):
+        """
+        This checks compatibility with older versions,
+        before the spelling was updated to "separator."
+        """
+        assert YAMLPath(yamlpath).seperator == pathsep
+
     def test_escaped(self):
         testpath = YAMLPath(r"abc.def\.ghi")
         assert list(testpath.escaped) == [
@@ -119,7 +132,7 @@ class Test_YAMLPath():
         ]
 
     def test_append(self):
-        yp = YAMLPath("", PathSeperators.DOT)
+        yp = YAMLPath("", PathSeparators.DOT)
         yp.append("abc")
         yp.append("def")
         yp.append("ghi").append("jkl").append("mno")
